# ganymede
#
# Hacking Jupyter's atmosphere
#
# Copyright (C) 2015 Stefan Zimmermann <zimmermann.code@gmail.com>
#
# ganymede is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# ganymede is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ganymede. If not, see <http://www.gnu.org/licenses/>.

from path import Path


DIR = Path(__file__).dirname()

SVG = DIR / 'ganymede.svg'

CSS = DIR / 'ganymede.css'

COFFEE = DIR / 'ganymede.coffee'
JS = DIR / 'ganymede.js'


if COFFEE.exists(): #==> development mode (not installed) ==> compile
    # import conditionally to avoid general dependency
    from coffeetools import coffee

    JS.write_text(coffee.compile(COFFEE.text(), bare=True))



from path import Path
from IPython.display import HTML

import ganymede


def test_ganymede():
    """Test internal functionality of the ganymede python package.
    """
    COFFEE, JS = [
      Path(ganymede.__file__).realpath().dirname()
      / 'static' / 'ganymede' + ext
      for ext in ['.coffee', '.js']]
    if COFFEE.exists():
        # make sure that no javascript exists
        # to check auto-generation from coffeescript
        JS.remove_p()
        assert not JS.exists()

    html = ganymede.load() # triggers coffeescript-->javascript compilation
    assert JS.exists()
    assert isinstance(html, HTML)



import sys
import os

from setuptools import setup

ROOT = os.path.dirname(os.path.realpath(__file__))

sys.path.insert(0, ROOT)

import ganymede
if os.path.exists(os.path.join(
  ROOT, 'ganymede', 'static', 'ganymede.coffee'
  )):
    # trigger ganymede.coffee-->.js compilation
    import ganymede.static


setup(
  name='ganymede',
  version=ganymede.__version__,
  description="Hacking Jupyter's atmosphere",

  author="Stefan Zimmermann",
  author_email="<zimmermann.code@gmail.com>",
  url="https://bitbucket.org/userzimmermann/ganymede",

  license='GPLv3',

  install_requires=open(os.path.join(ROOT, 'requirements.txt')).read(),

  packages=[
    'ganymede',
    'ganymede.static',
    ],
  package_data={
    'ganymede.static': ['*.svg', '*.css', '*.js'],
    },

  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: GNU General Public License (GPL)',
    'Operating System :: OS Independent',
    'Topic :: Software Development',
    'Topic :: Utilities',
    ],
  keywords=[
    'ganymede', 'jupyter', 'ipython', 'notebook',
    ],
  )



# ganymede
#
# Hacking Jupyter's atmosphere
#
# Copyright (C) 2015 Stefan Zimmermann <zimmermann.code@gmail.com>
#
# ganymede is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# ganymede is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ganymede. If not, see <http://www.gnu.org/licenses/>.

import sys
from base64 import b64encode
import json

__version__ = '0.1.dev1'


def load():
    """Generate and return Ganymede HTML containing CSS and JavaScript
       for modifying the Jupyter notebook web interface.
    """
    # make sure that .static pkg gets reloaded on %reload_ext ganymede
    # to recompile ganymede.coffee in development (non-installed) mode
    sys.modules.pop('ganymede.static', None)
    from ganymede.static import CSS, JS, SVG

    # import locally to make this module importable in setup.py
    # without further dependencies
    from IPython.display import HTML

    return HTML("""
      <style id="ganymede-style" type="text/css">%s</style>
      <script type="text/javascript">
        %s
        window.ganymede = new Ganymede(%s);
      </script>
      <script type="text/javascript">
        $('#ganymede-style').on('remove', function () {
            window.ganymede.unload();
        });
      </script>
      """ % (CSS.text(), JS.text(),
             json.dumps('data:image/svg+xml;base64,%s'
                        % b64encode(SVG.bytes()).decode('ascii'))))


def load_ipython_extension(shell):
    """Called on ``%load_ext ganymede`` and ``%reload_ext ganymede``
    """
    # import locally to make this module importable in setup.py
    # without further dependencies
    from IPython.display import display

    display(load())
